# CMG: A Computational Model of Cognitive Maps: Analyzing Violent and Nonviolent Activity in Egypt and Germany

This directory contains the code and data files needed to reproduce the results
presented in *A Computational Model of Cognitive Maps: Analyzing Violent and
Nonviolent Activity in Egypt and Germany*.

## Requirements

- Unix-like operating system with `make` and `curl` utilities
- Matlab
  - [Statistics Toolbox](http://www.mathworks.com/products/statistics/)
  - [Econometrics Toolbox](http://www.mathworks.com/products/econometrics/?s_cid=HP_FP_ML_EconometricsToolbox)
- [Graphviz](http://www.graphviz.org/) (optional)

The code was produced on Mac OS X 10.6 to 10.9 and
[Fedora](https://fedoraproject.org/‎) versions 18 to 20 with Matlab versions
2011a and greater.  The code has not been tested on any Windows operating
system.

## Data files

The data for the individual cognitive maps is located in the `data_csv/`
directory.  The JSON file `data_csv_list.json` has a list of the base names
(file name minus `.csv`) for all of the individual cognitive map files.  The
format of the data files is described in `data_csv/README.md`.

The sets of classes for each hypothesis defined in the article are stored in the
JSON file `hypothesis_class_sets.json`.

Results from the Monte Carlo simulations and the "all combinations" experiment
are included with these files, because they take around 2 weeks to produce on a
single workstation.  The Monte Carlo results are stored in the
`cmg_monte_carlo_data/` directory.  The results from the "all combinations"
experiment is stored in `cmg_all_combo.mat`.  Instructions to reproduce these
results are included below.  The plots and tables may be produced with the saved
data.

## Instructions

### Download external toolboxes

The CMG code requires several toolboxes as indicated in `toolbox/README.md`.
The `bnt` and `bgl` toolboxes are not included with this code, but may be easily
downloaded with the following steps:

- Open a terminal (on Mac use `/Applications/Utilities/Terminal.app`)
- Change directory to `cmg/toolbox`
- Enter the command `make`

For example if you've downloaded `cmg.zip` to the `~/Downloads` directory then
open a terminal and enter the following commands:

```
$ cd ~/Downloads
$ unzip cmg.zip
$ cd cmg/toolbox
$ make
```

The `make` command will download and unpack the required toolboxes.

### Matlab setup

The working directory in Matlab needs to be `cmg` for the utilities to work.
Also, the `cmg_setup` must be run to add the toolboxes to the Matlab path.  This
must be done anytime Matlab is restarted, because the setup script does not
permanently modify the Matlab path.

Example when running Matlab from a terminal:

```
$ matlab -nodesktop
>> ls
cmg	cmg.zip
>> cd cmg
>> cmg_setup
Warning: Function assert has the same name as a MATLAB builtin. We suggest you rename
the function to avoid a potential name conflict.
> In path at 109
  In addpath at 86
  In cmg_setup at 14
```

Note that the warning shown above may be safely ignored when running the CMG
scripts.  It is a good idea to restart Matlab before working with other projects
that may use the `assert` function.

### Generate tables and plots

The following commands generate the tables and plots displayed in the article.
Note that these commands require the simulation output in the
`cmg_monte_carlo_data/` directory and `cmg_all_combo.mat` file.  To produce the
results start Matlab, change to the `cmg` directory, and execute the following
commands:

1. `>> cmg_setup`
2. `>> cmg_run_hypothesis`
  - produces `hypothesis_decision_counts.json`
3. `>> cmg_pvalue`
  - displays hypothesis p-values in Matlab output
4. `>> cmg_hypo_plot`
  - generates `cmg_hypo_plot.pdf`
5. `>> cmg_ks_test`
  - requires statistics toolbox
  - displays ks test information in Matlab output
  - generates `cmg_ecdf_plot.pdf`
6. `>> cmg_corrplot`
  - requires econometrics toolbox
  - generates `cmg_corrplot.png`
7. `>> cmg_all_combo_process`
  - requires `cmg_all_combo.mat`
  - produces `cmg_all_combo_table.csv`
  - produces `cmg_all_combo_plots/*.eps` (decision count histograms)

### Collect simulation data

#### Monte Carlo simulation

The CMG Monte Carlo simulation produces distributions of decision counts based
on random combinations of asserted belief classes.  The simulation code for a
given number of active classes and samples is in the file `cmg_monte_carlo.m`.
The parameters of the simulation are:

- number of active classes (integer from 0 to 105)
- number of samples (30,000 used by default)
- a JSON specification file `cmg_monte_carlo.json`
  - defines location of individual maps
  - defines output directory
  - other parameters, i.e. delimiter

The most direct way to collect the simulation data is to run the Matlab code in
`cmg_monte_carlo_run.m`.  This executes `cmg_monte_carlo(x,30000)` for `x` from
`0` to `105`.  The data is stored in the directory `cmg_monte_carlo_data/`.
This takes about 13 days on a workstation.  To run this script startup Matlab,
change to the `cmg` directory and execute the following:

```
>> cmg_setup
...
>> cmg_monte_carlo_run
cmg_monte_carlo_run: running 0 / 105
cmg_monte_carlo_run: running 1 / 105
cmg_monte_carlo_run: running 2 / 105
cmg_monte_carlo_run: running 3 / 105
...
```

It is also possible to collect the data using a batch-queuing computing system.
The script `cmg_monte_carlo_run.sh` will work on a system with the Sun Grid
Engine.  To submit a job, change to the `cmg` directory and execute the
following:

```
$ qsub cmg_monte_carlo_run.sh
```

The results in the directory `cmg_monte_carlo_data/` are used in many of the
data processing steps.

#### All combinations experiment

The CMG "all combinations" experiment is performed with the Matlab code in
`cmg_all_combo.m`.  To run this code start Matlab, change to the `cmg`
directory, and execute the following:

```
>> cmg_setup
...
>> cmg_all_combo
cmg_all_combo: 1 / 131072 complete (22.0475 h remaining)
cmg_all_combo: 2 / 131072 complete (19.4255 h remaining)
cmg_all_combo: 3 / 131072 complete (18.2142 h remaining)
cmg_all_combo: 4 / 131072 complete (17.6813 h remaining)
cmg_all_combo: 5 / 131072 complete (17.3568 h remaining)
cmg_all_combo: 6 / 131072 complete (17.1658 h remaining)
cmg_all_combo: 7 / 131072 complete (17.0143 h remaining)
cmg_all_combo: 8 / 131072 complete (16.9941 h remaining)
cmg_all_combo: 9 / 131072 complete (16.9774 h remaining)
cmg_all_combo: 10 / 131072 complete (16.9053 h remaining)
...
```

The output file is `cmg_all_combo.mat` and is used by
`cmg_all_combos_process.m`.
