%cmg_all_combo  perform all combinations experiment

function cmg_all_combo

% import cmg data
data_files = cmg_json_load('data_csv_list.json')';
Gset = cmg_import_set(data_files,'data_csv/','.csv',0,';');
bnet_set = cmg_bnet_set(Gset);

% map type indices
map_idx.NV = 1:14;
map_idx.V = 15:27;

% define experimental set of belief classes
exp_set = {
  'absence-of-aggression-by-home-state'
  'absence-of-domination-by-foreign-state'
  'absence-of-domination-by-home-state'
  'absence-of-state-structures'
  'aggression-by-home-state'
  'aggression-by-previous-state'
  'change-of-home-state'
  'continuation-of-aggression-by-home-state'
  'domination-by-home-state'
  'domination-by-previous-state'
  'education-of-the-people'
  'ignorance-of-fellow-citizens'
  'imperialism'
  'religious-state'
  'strained-living-conditions'
  'support-by-home-state'
  'unreligious-state'
  };

% define default set of belief classes
default_set = {
  'absence-of-strength-of-home-state'
  'efficient-structure-of-violent-group'
  'acceptance-of-state-structures'
  'political-goal'
  'self-conviction'
  'weakness-of-home-state'
  'peaceful-activity'
  'existence-of-peaceful-activity-against-home-state'
  'existence-of-international-resistance-against-state-system'
  };

% total number of trials
num_classes = length(exp_set);
num_trials = 2^num_classes;
%num_trials = 30;

% data to save
dec_count_nv = zeros(num_trials,1);
dec_count_v = zeros(num_trials,1);
assert_lx = false(num_trials,num_classes);

% run maps on all combinations of experimental set
tic
for i = 1:num_trials
  assert_lx(i,:) = dec2bin_lx(i-1,num_classes);
  active_set = [default_set; exp_set(assert_lx(i,:))];
  S = cmg_sample_set(Gset,bnet_set,active_set,{},{'v','nv'});
  dec_count_nv(i) = sum(S.map_lx(map_idx.NV));
  dec_count_v(i) = sum(S.map_lx(map_idx.V));
  remaining_time = (num_trials-i) * toc / i / 3600;
  fprintf('cmg_all_combo: %d / %d complete (%g h remaining)\n',i,num_trials,remaining_time);
end
AC.total_time = toc;

% prepare output structure
AC.exp_set = exp_set;
AC.default_set = default_set;
AC.dec_count_nv = dec_count_nv;
AC.dec_count_v = dec_count_v;
AC.assert_lx = assert_lx;

save('cmg_all_combo.mat','AC');

%keyboard

end

function y = dec2bin_lx(x,n)
y = dec2bin(x,n) == '1';
end
