%cmg_all_combo_process  generate decision matrix and decision histograms

function cmg_all_combo_process

% load data
load('cmg_all_combo.mat');

% generate decision matrix
%  each column corresponds to a number of NV decisions
%  each row corresponds to a number of V decisions
max_nv = max(AC.dec_count_nv);
max_v = max(AC.dec_count_v);
dec_mat = zeros(max_v+1,max_nv+1);
for i = 1:length(AC.dec_count_nv)
  nv = AC.dec_count_nv(i);
  v = AC.dec_count_v(i);
  dec_mat(v+1,nv+1) = dec_mat(v+1,nv+1) + 1;
end
% convert to a matlab dataset
name_nv = cellfun(@(x) ['nv_' x],num2strcell(0:max_nv),'UniformOutput',false);
name_v = cellfun(@(x) ['v_' x],num2strcell(0:max_v),'UniformOutput',false);
dec_ds = mat2dataset(dec_mat,'VarNames',name_nv,'ObsNames',name_v);
% export dataset as a csv file
export(dec_ds,'file','cmg_all_combo_table.csv','Delimiter',',');

% create output directory for plots
mkdir('cmg_all_combo_plots')

% plot all histograms
for i = 1:length(AC.exp_set)
  fprintf('working on: %s\n',AC.exp_set{i});

  figure(1); clf;
  
  % v maps
  v_on = AC.dec_count_v(AC.assert_lx(:,i) == 1);
  v_off = AC.dec_count_v(AC.assert_lx(:,i) == 0);
  [c_v_on, v_out1] = hist(v_on,0:max_v);
  [c_v_off,v_out2] = hist(v_off,0:max_v);

  % plot v
  subplot(1,2,1);
  bar(v_out1,[c_v_on' c_v_off'])
  xlim([-.5 max_v+.5])
  ylabel('V count')
  xlabel('number of decisions')
  
  % nv maps
  nv_on = AC.dec_count_nv(AC.assert_lx(:,i) == 1);
  nv_off = AC.dec_count_nv(AC.assert_lx(:,i) == 0);
  [c_nv_on, nv_out1] = hist(nv_on,0:max_nv);
  [c_nv_off, nv_out2] = hist(nv_off,0:max_nv);

  % plot v
  subplot(1,2,2);
  bar(nv_out1,[c_nv_on' c_nv_off'])
  xlim([-.5 max_nv+.5])
  ylabel('NV count')
  xlabel('number of decisions')

  % print the title
  suplabel(AC.exp_set{i},'t');
  
  % save the figure
  print(['cmg_all_combo_plots/' AC.exp_set{i} '.eps'],'-depsc2')
  
  % carry out the ks test
  [v_h,v_p,v_ks2stat] = kstest2(v_on,v_off);
  [nv_h,nv_p,nv_ks2stat] = kstest2(nv_on,nv_off);
  fprintf('  ks v:  %g\n',v_ks2stat);
  fprintf('  ks nv: %g\n',nv_ks2stat);
  
end

%keyboard

end

function samples = expand_hist(h)
%expand_hist  expand histogram of bin counts to vector of samples

samples = [];
for i = 1:length(h)
  samples = [samples; (i-1)*ones(h(i),1)];
end

end