%cmg_hypo_plot  generate hypothesis plot

function cmg_hypo_plot

% select the map set
map_set = 'ALL';

% monte carlo directory
mc_dir = 'cmg_monte_carlo_data/';

% number of files
mc_num = 106;

% load the monte carlo data to get
%     mean, std, min, max
mc_mean = zeros(mc_num,1);
mc_std = zeros(mc_num,1);
mc_min = zeros(mc_num,1);
mc_max = zeros(mc_num,1);

for i = 1:mc_num
  num_classes = i - 1;
  mc_file = sprintf([mc_dir 'cmgmc-%d-30000.mat'],num_classes);
  load(mc_file)
  dist = MC.(map_set)';
  bins = (0:length(dist)-1)';
  prob = dist / sum(dist);
  mc_mean(i) = prob' * bins;
  mc_std(i) = sqrt(prob'*(bins-mc_mean(i)).^2);
  mc_min(i) = min(find(dist > 0))-1;
  mc_max(i) = max(find(dist > 0))-1;
end

xmax = 22;
ymax = max(mc_max(1:xmax+1));
xval = 0:mc_num-1;

figure(1); clf; hold on;

plot(xval,mc_mean,'b','LineWidth',2);
plot(xval,mc_mean + mc_std,'g','LineWidth',2);
plot(xval,mc_mean - mc_std,'r','LineWidth',2);
plot(xval,mc_min,'c','LineWidth',2);
plot(xval,mc_max,'m','LineWidth',2);

xlim([0 xmax])
ylim([0 ymax])

title([map_set ' distribution summary (2014-04-29)'],'FontSize',16)
xlabel('number of asserted BCs','FontSize',16)
ylabel('decision count','FontSize',16)
legend('mean','+std','-std','min','max','Location','NorthWest')

% plot hypothesis points
hypo = cmg_json_load('hypothesis_decision_counts.json');
for f = fields(hypo)'
    fs = f{1};
    plot(hypo.(fs).num_classes,hypo.(fs).(map_set),'k',...
        'MarkerSize',20,'Marker','.');
    os = .3;
    text(hypo.(fs).num_classes+os,hypo.(fs).(map_set)+os,fs);
end

print('cmg_hypo_plot.pdf','-dpdf')
%keyboard

% load an plot all hypothesis points

% plot

end
