%cmg_ks_test plot empirical cdfs and ks statistic to compare v and nv

function cmg_ks_test

% settings
set_a = 'V';
set_b = 'NV';
num_classes = 19;

% load data
filename = sprintf('cmg_monte_carlo_data/cmgmc-%d-30000.mat',num_classes);
load(filename);

% get decision histograms
hist_a = MC.(set_a);
hist_b = MC.(set_b);

% get samples and normalize
samp_a = expand_hist(hist_a) / (length(hist_a) - 1);
samp_b = expand_hist(hist_b) / (length(hist_b) - 1);

% get the empirical cdf
[cdf_a, x_a] = ecdf(samp_a);
[cdf_b, x_b] = ecdf(samp_b);

figure(1);
clf;
hold on;
stairs(x_a,cdf_a,'b','LineWidth',2);
stairs(x_b,cdf_b,'r','LineWidth',2);

legend(set_a,set_b,'Location','NorthWest');
xlabel('Proportion of decisions made')
ylabel('Cumulative probability')
title_str = sprintf('Empirical CDF %s & %s with %d active classes', ...
  set_a, set_b, num_classes);
title(title_str)

% save figure
print('cmg_ecdf_plot.pdf','-dpdf');

% perform the ks test
[ks_h,ks_p,ks_stat] = kstest2(samp_a,samp_b);
fprintf('--- ks test results ---\n');
fprintf('note: null hypothesis is that both samples come from same distribution\n');
fprintf('ks_h: %d (1 = reject null hypothesis)\n',ks_h);
fprintf('ks_p: %g\n',ks_p);
fprintf('ks_stat: %g\n',ks_stat);

%keyboard

end

function samples = expand_hist(h)
%expand_hist  expand histogram of bin counts to vector of samples

samples = [];
for i = 1:length(h)
  samples = [samples; (i-1)*ones(h(i),1)];
end

end