%cmg_monte_carlo  run monte carlo on cmg data to get decision count dist.

function cmg_monte_carlo(num_active, num_sample)

% load the json settings file
conf = cmg_json_load('cmg_monte_carlo.json');

% create the output directory
[mkdir_check mkdir_mess mkdir_messid] = mkdir(conf.output_dir);
if ~mkdir_check
  error('cmg_monte_carlo:bad_ouput_dir','specified output directory is bad');
end

% load the cmgs
Gset = cmg_import_set(conf.maps, ...
  conf.data_dir, ...
  conf.file_ext, ...
  conf.inference_count, ...
  conf.delimiter);

num_map = length(Gset);

% construct the bnets
bnet_set = cmg_bnet_set(Gset);

% set the rng seed
rng(num_active*num_sample);

% map type indices
hist_idx.NV = 1:14;
hist_idx.NVE = 1:8;
hist_idx.NVG = 9:14;
hist_idx.V = 15:27;
hist_idx.VE = 15:21;
hist_idx.VG = 22:27;
hist_idx.E = [hist_idx.NVE hist_idx.VE];
hist_idx.G = [hist_idx.NVG hist_idx.VG];
hist_idx.ALL = 1:27;

hist_fields = fieldnames(hist_idx);
hist_num = length(hist_fields);

% set up output structure
MC.conf = conf;
MC.num_active = num_active;
MC.num_sample = num_sample;
MC.num_map = num_map;

for j = 1:hist_num
  MC.(hist_fields{j}) = zeros(1,length(hist_idx.(hist_fields{j}))+1);
end

% get set of all classes
all_classes = cmg_all_classes(Gset);

% set of decision classes
dec_classes = {'nv'; 'v'};

% remove 'nv' and 'v'
exp_classes = setdiff(all_classes,dec_classes);
num_classes = length(exp_classes);

% count number of possible combinations
num_combos = nchoosek(num_classes,num_active);

if num_combos <= num_sample
  % run all combinations
  % indicate method
  MC.method = 'enumerate';
  % get all combinations
  sample_combos = nchoosek(1:num_classes,num_active);
  decision_matrix = false(num_combos,num_map);
  tic
  for i = 1:num_combos
    % get a random permutation
    perm = sample_combos(i,:);
    % run the maps
    S = cmg_sample_set(Gset,bnet_set,exp_classes(perm),{},dec_classes);
    % store decision
    decision_matrix(i,:) = S.map_lx';
    % store data in histograms
    for j = 1:hist_num
      hist_count = sum(S.map_lx(hist_idx.(hist_fields{j})))+1;
      MC.(hist_fields{j})(hist_count) = MC.(hist_fields{j})(hist_count) + 1;
    end
  end
  MC.time = toc;
else
  % perform monte_carlo
  % indicate method
  MC.method = 'monte_carlo';
  sample_combos = zeros(num_sample,num_active);
  decision_matrix = false(num_sample,num_map);
  tic
  % start loop monte carlo loop
  for i = 1:num_sample
    % get a random permutation
    perm = randperm(num_classes,num_active);
    % store the sample combination
    sample_combos(i,:) = perm;
    % run the maps
    S = cmg_sample_set(Gset,bnet_set,exp_classes(perm),{},dec_classes);
    % store the decision
    decision_matrix(i,:) = S.map_lx';
    % store data in histograms
    for j = 1:hist_num
      hist_count = sum(S.map_lx(hist_idx.(hist_fields{j})))+1;
      MC.(hist_fields{j})(hist_count) = MC.(hist_fields{j})(hist_count) + 1;
    end
  end
  MC.time = toc;
end

% store data in structure
MC.sample_combos = sample_combos;
MC.decision_matrix = decision_matrix;
MC.hist_idx = hist_idx;

% save the data
output_filename = sprintf('cmgmc-%d-%d.mat',num_active,num_sample);
save([conf.output_dir output_filename],'MC');
%keyboard

end
