%cmg_expand  expands predicate consequent lists
%
% Input:
%  P = cell array of predicate sets, each set stored as cell array of
%      strings
%  C = cell array of consequents, each consequent stored as a string
%
% Output:
%  PE = expanded cell array of predicate strings
%  CE = expanded cell array of consequent strings
%
% Example:
%  >> P = {{'a' 'b'}; {'c'}};
%  >> C = {'c'; 'd'};
%  >> [PE CE] = cmg_expand(P,C)
%
%  PE = 
%
%    'a'
%    'b'
%    'c'
%
%  CE = 
%
%    'c'
%    'c'
%    'd'
%  

function [PE CE] = cmg_expand(P,C)

% get lengths of P and C
np = length(P);
nc = length(C);

% validate the input
if ~isvector(P) || ~iscell(P) || ~isvector(C) || ~iscell(C) || np ~= nc
  error('cmg_expand:input',['P and C must be cell array vectors of ' ...
    'same length.'])
end

% create empty cells, these will contain expanded predicate list and
% expanded consequent list
PE = {};
CE = {};

% loop through all elements in P and C
for i = 1:np
  % get the predicate set
  ps = P{i};
  
  % get the length of the predicate set
  nps = length(ps);
  
  % append to expanded cell arrays
  for j = 1:nps
    PE = [PE ps{j}];
    CE = [CE C{i}];
  end
end

% orient PE and CE as columns
PE = PE(:);
CE = CE(:);

end