%cmg_import  import a cognitive map graph from a csv or xls file
%
% Input:
%  filename = xls or csv filename
%
% Output:
%  Pstr = cell array of predicate strings, multiple predicates are
%         separated by semicolons
%  C = cell array of consequents (stored as strings)
%

function [Pstr C] = cmg_import(filename,delimiter)

% default delimiter
if nargin < 2 || isempty(delimiter)
  delimiter = ',';
end
  
% get file extension
file_ext = filename(end-3:end);

switch file_ext
  case '.csv'
    
    % open the file
    fid = fopen(filename);
    
    % read the file with text scan
    % the %q specifier removes quotations!
    txt = textscan(fid,'%q %q','Delimiter',delimiter);
    
    % close the file
    fclose(fid);
    
    % separate the input
    Pstr = txt{:,1};
    C = txt{:,2};
    
  case '.xls'
    
    % get info on the file
    [status sheets format] = xlsfinfo(filename);
    
    if strcmp(status,'')
      % could not open the file
      error('cmg_import:xlsread is unable to read file: %s',filename);
    end
    
    % read the file
    [num txt raw] = xlsread(filename);
    % variable txt is now populated with the tabular data from the excel file
    
    % separate the input
    Pstr = txt(:,1);
    C = txt(:,2);
    
  otherwise
    error('cmg_import:unknown_extension','filename has unknown extension.')
end

% remove the whitespace around class names
Pstr = cmg_str_rmws(Pstr);
C = cmg_str_rmws(C);

end
