%cmg_import_set  import a set of cmgs from a cell array of filenames
%
% Usage:
%   cmg_import_set(filename_cell)
%   cmg_import_set(filename_cell,data_dir)
%   cmg_import_set(filename_cell,data_dir,file_ext)
%   cmg_import_set(filename_cell,data_dir,file_ext,inference_count)
%   cmg_import_set(filename_cell,data_dir,file_ext,inference_count,delimiter)
%
% Input:
%   filename_cell = cell of filenames to load
%   data_dir = optional location of data file director, defaults to 'data_xls/'
%   file_ext = optional file extension, defaults to '.xls'
%   inference_count = optional inference_count flag, defaults to 0
%   delimiter = optional choice for delimiter, defaults to ','
%
% Output:
%   Gset = array of cmg structures
%
function Gset = cmg_import_set(filename_cell,data_dir,file_ext, ...
    inference_count, delimiter)

  % handle optional input
  if nargin < 5 || isempty(delimiter)
    delimiter = ',';
  end
  
  if nargin < 4 || isempty(inference_count)
    inference_count = 0;
  end

  if nargin < 3 || isempty(file_ext)
    file_ext = '.xls';
  end

  if nargin < 2 || isempty(data_dir)
    data_dir = 'data_xls/';
  end

  num_files = length(filename_cell);

  for i = 1:num_files
    filename = [data_dir filename_cell{i} file_ext];
    [P C] = cmg_import(filename,delimiter);
    Gset(i) = cmg_struct(P,C,filename_cell{i},inference_count);
  end

  % orient the data
  Gset = Gset(:);
  
end
