%cmg_sample_set  return cmg sample struct
%
% Input:
%  Gset = set of cmgs
%  bnet_set = set of bnet objects
%  on_list = list of classes to assert as on
%  off_list = list of classes to assert as off
%  decision_set = set of classes that are decisions
%
% Output:
%  S = cmg sample struct
%
% Struct fields:
%  map_lx = logical index of maps that make decisions
%  map_set = cell array of name of maps that make decisions
%  map_dec = cell array of decisions that each map makes
%  map_act = cell array of activated classes in each map
%  decision_set = set of all pure_consequents made
%  active_classes = set of all activated classes
%  P_combo = all predicate sets that are activated in at least one map
%  C_combo = all consequents that are activated in at least one map
%

function S = cmg_sample_set(Gset,bnet_set,on_list,off_list,decision_set)

  % handle optional input
  if nargin < 5 || isempty(decision_set)
    decision_set = {};
  end

  num_cmg = length(Gset);

  % allocate struct fields
  S.map_lx = false(num_cmg,1);
  S.map_set = {};
  S.map_dec = {};
  S.map_act = {};
  S.decision_set = {};
  S.active_classes = {};
  S.Pstr_combo = {};
  S.C_combo = {};

  % sample from all maps
  for i = 1:num_cmg

    % run the sample
    [active_cons active_class result active_lx inference_lx] = ...
        cmg_sample(Gset(i),bnet_set(i),on_list,off_list,decision_set);

    % store decisions made by map
    S.map_dec{i} = active_cons;

    % store activated classes for each map
    S.map_act{i} = active_class;

    % save data related to decisions
    if length(active_cons) > 0
      S.map_lx(i) = true;
      S.map_set = [S.map_set; Gset(i).name];
      S.decision_set = [S.decision_set; active_cons];
    end

    % save activated classes
    S.active_classes = [S.active_classes; active_class(:)];

    % save data related to inferences
    S.Pstr_combo = [S.Pstr_combo; Gset(i).Pstr(inference_lx)];
    S.C_combo = [S.C_combo; Gset(i).C(inference_lx)];

  end

  % orient the output data
  S.map_set = S.map_set(:);
  S.map_dec = S.map_dec(:);
  S.map_act = S.map_act(:);
  S.decision_set = unique(S.decision_set(:));
  S.active_classes = unique(S.active_classes(:));
  S.Pstr_combo = S.Pstr_combo(:);
  S.C_combo = S.C_combo(:);

end
