%cmg_test_dag  checks if a cognitive map graph is a dag
%
% This function tests whether a cognitive map graph defined by predicate
% cell array P and consequent cell array C is directed and acyclic.
%
% Input:
%  P = predicate cell array
%  C = consequent cell array
%
% Output:
%  isdag = 1 if graph defined by P and C is directed and acyclic
%          0 if graph defined by P and C contains cycles
%

function isdag = cmg_test_dag(P,C)

% expand the cell arrays
[PE CE] = cmg_expand(P,C);

% get the list of unique classes
class_list = unique([PE; CE]);

% build adjacency matrix using bnt
A = mk_adj_mat([PE CE],class_list);

% test the dag property using bgl
isdag = test_dag(sparse(A));

end